@@ -14,6 +14,7 @@ from typing import (
     TypeVar,
     NewType,
     Iterable,
+    Set,
 )
 
 import typic
@@ -109,7 +110,9 @@ class Scene:
 
     @typic.cached_property
     def id(self) -> NodeID:
-        return NodeID(parameterize(f"{self.act}-{self.type.lower()}-{self.col}"))
+        return NodeID(
+            f"{self.act}-{self.type.lower()}-{roman.numeral(self.num).lower()}"
+        )
 
     @typic.cached_property
     def col(self) -> str:
@@ -240,10 +243,20 @@ class Persona:
     def id(self) -> NodeID:
         return NodeID(parameterize(self.name))
 
+    @typic.cached_property
+    def ids(self) -> Set[NodeID]:
+        return {NodeID(parameterize(n.strip())) for n in self.name.split("&")}
+
+    @property
+    def is_multi(self) -> bool:
+        return "&" in self.name
+
     @classmethod
     def from_node(cls, node: "GenericNode") -> "Persona":
         return cls(
-            index=node.index, text=node.match_text, name=titleize(node.match_text),
+            index=node.index,
+            text=node.match_text,
+            name=titleize(node.match_text),
         )
 
 
@@ -372,6 +385,10 @@ class Speech:
         linenos = sorted((x.lineno for x in self.body if isinstance(x, Dialogue)))
         return linenos[0], linenos[-1]
 
+    @typic.cached_property
+    def linepart(self) -> int:
+        return next((x.linepart for x in self.body if isinstance(x, Dialogue)), 0)
+
     @typic.cached_property
     def num_lines(self) -> int:
         x, y = self.linerange
@@ -381,11 +398,13 @@ class Speech:
 
     @typic.cached_property
     def id(self) -> NodeID:
-        return NodeID(
+        uri = (
             f"{self.scene}-{self.persona}-{self.type.lower()}-"
-            f"{'{0}-{1}'.format(*self.linerange)}"
-            f"-{self.index}"
+            f"{'-'.join(map(str, self.linerange))}"
         )
+        if self.linepart:
+            uri += f"-{roman.numeral(self.linepart).lower()}"
+        return NodeID(uri)
 
 
 @typic.klass(unsafe_hash=True, slots=True)
